<? require_once("inc/header.php"); ?>
<table>
  <tr>
   <td class="contentTopic">
   Bacula Documentation
   </td>
   </tr>
   
  <tr>
   <td class="content">
   <ul>
   <li> <a href="dev-manual/Brief_Tutorial.html">Tutorial</a>
    <br>(start here after installing Bacula)
   </ul>
   </td>
   <td class="content">
   <ul>
         <li> <a href="<? echo $spath ?>/?page=news"> News </a>What's New in Bacula</a>
           <br>(changes since the last major release)
   </ul>
   </td>
   </tr>
     
   <tr>
     <td class="content">
   <ul>
   <li> <a href="rel-manual/index.html" >HTML User's Manual</a>
    <br>(released version of the User's Manual)<br></li>
   <li> <a href="<? echo $spath ?>/rel-bacula.pdf">PDF User's Manual</a>
    <br>(released version of the User's Manual)<br></li>
   </ul>
   </td>
   <td class="content">
   <ul>
   <li> <a href="dev-manual/index.html" >HTML Development Manual</a>
    <br>(User's manual for code under development)<br></li>
   <li> <a href="<? echo $spath ?>/bacula.pdf">PDF Development Manual</a>
    <br>(User's Manual for code under development)</li>
   </ul>
   </td>
   </tr>
   
   <tr>
     <td class="content">
      <ul>
      <li><a href="bacula-web/index.html">Bacula-web Guide</a>
      <br>(Guide for the Bacula-web GUI application)</li>
      </ul>
     </td>

     <td class="content">
      <ul>
      <li><a href="developers/index.html">HTML Developer's Guide</a>
      <br>(Guide for Bacula developers)</li>
      <li> <a href="<? echo $spath ?>/developers.pdf">PDF Developer's Guide</a>
      <br>(Guide for Bacula developers)</li>
      <li><a href="<? echo $spath ?>/FLA-bacula.en.pdf">PDF FLA</a>
      <br>(Developer's Fiduciary License Agreement)</li>
      </ul>
     </td>
   </tr>



</table>
 <p>
<? require_once("inc/footer.php"); ?>
